@@ -19,6 +19,7 @@ func main() {
 	configRules = append(configRules, rules.AdobeClientID())
 	configRules = append(configRules, rules.AdobeClientSecret())
 	configRules = append(configRules, rules.AgeSecretKey())
+	configRules = append(configRules, rules.AlgoliaApiKey())
 	configRules = append(configRules, rules.AlibabaAccessKey())
 	configRules = append(configRules, rules.AlibabaSecretKey())
 	configRules = append(configRules, rules.AsanaClientID())
@@ -80,7 +81,8 @@ func main() {
 	configRules = append(configRules, rules.NewRelicBrowserAPIKey())
 	configRules = append(configRules, rules.NPM())
 	configRules = append(configRules, rules.PlanetScalePassword())
-	configRules = append(configRules, rules.PlanetScaleToken())
+	configRules = append(configRules, rules.PlanetScaleAPIToken())
+	configRules = append(configRules, rules.PlanetScaleOAuthToken())
 	configRules = append(configRules, rules.PostManAPI())
 	configRules = append(configRules, rules.PrivateKey())
 	configRules = append(configRules, rules.PulumiAPIToken())
