@@ -13,9 +13,9 @@ func GenericCredential() *config.Rule {
 			"key",
 			"api[^Version]",
 			"token",
-			"pat",
 			"secret",
 			"client",
+			"passwd",
 			"password",
 			"auth",
 		}, `[0-9a-z\-_.=]{10,150}`),
@@ -26,7 +26,7 @@ func GenericCredential() *config.Rule {
 			"token",
 			"secret",
 			"client",
-			"pat",
+			"passwd",
 			"password",
 			"auth",
 		},
